%define anolis_release 1

%global toolchain clang
%undefine _include_frame_pointers

Name:		lldb
Version:	16.0.6
Release:	%{anolis_release}%{?dist}
Summary:	Next generation high-performance debugger

License:	Apache-2.0 WITH LLVM-exception OR NCSA
URL:		http://lldb.llvm.org/
Source0:	https://github.com/llvm/llvm-project/releases/download/llvmorg-%{version}/%{name}-%{version}.src.tar.xz

Patch0: 	0001-lldb-Change-LLVM_COMMON_CMAKE_UTILS-usage.patch

BuildRequires:	ninja-build clang cmake
BuildRequires:	llvm-static = %{version} llvm-devel = %{version} llvm-test = %{version}
BuildRequires:	clang-devel = %{version} swig
BuildRequires:	libffi-devel libxml2-devel libedit-devel
BuildRequires:	zlib-devel python3-lit ncurses-devel doxygen

Requires:	python3-lldb = %{version}

%description
LLDB is a next generation, high-performance debugger. It is built as a set of reusable components 
which highly leverage existing libraries in the larger LLVM Project, such as the Clang expression 
parser and LLVM disassembler.

LLDB is the default debugger in Xcode on macOS and supports debugging C, Objective-C and C++ on 
the desktop and iOS devices and simulator.

%package devel
Summary:	Development header files for LLDB
Requires:	%{name} = %{version}-%{release}

%description devel
The package contains header files for the LLDB debugger.

%package -n python3-lldb
%{?python_provide:%python_provide python3-lldb}
Summary:	Python module for LLDB
BuildRequires:	python3-devel python3-setuptools
Requires:	%{name} = %{version}-%{release}
Requires:	python3-six

%description -n python3-lldb
The package contains the LLDB Python module.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -n %{name}-%{version}.src -p2

%build
%global _lto_cflags -flto=thin

%cmake  -GNinja \
	-DCMAKE_BUILD_TYPE=RelWithDebInfo \
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DLLVM_LINK_LLVM_DYLIB:BOOL=ON \
	-DLLVM_CONFIG:FILEPATH=/usr/bin/llvm-config-%{__isa_bits} \
        -DLLVM_COMMON_CMAKE_UTILS=%{_libdir}/cmake/llvm/ \
	\
	-DLLDB_DISABLE_CURSES:BOOL=OFF \
	-DLLDB_DISABLE_LIBEDIT:BOOL=OFF \
	-DLLDB_DISABLE_PYTHON:BOOL=OFF \
	-DLLVM_LIBDIR_SUFFIX=64 \
	\
	-DPYTHON_EXECUTABLE:STRING=%{__python3} \
	-DPYTHON_VERSION_MAJOR:STRING=$(%{__python3} -c "import sys; print(sys.version_info.major)") \
	-DPYTHON_VERSION_MINOR:STRING=$(%{__python3} -c "import sys; print(sys.version_info.minor)") \
	-DLLVM_EXTERNAL_LIT=%{_bindir}/lit \
	-DCLANG_LINK_CLANG_DYLIB=ON \
	-DLLVM_LIT_ARGS="-sv \
	--path %{_libdir}/llvm" \

%cmake_build

%install
%cmake_install

# remove static libraries
rm -fv %{buildroot}%{_libdir}/*.a
# python: fix binary libraries location
liblldb=$(basename $(readlink -e %{buildroot}%{_libdir}/liblldb.so))
ln -vsf "../../../${liblldb}" %{buildroot}%{python3_sitearch}/lldb/_lldb.so
%py_byte_compile %{__python3} %{buildroot}%{python3_sitearch}/lldb

# remove bundled six.py
rm -f %{buildroot}%{python3_sitearch}/six.*

%generate_compatibility_deps

%files
%license LICENSE.TXT
%dir %{abidir}
%{_bindir}/lldb*
%{abidir}/lldb*-option.list
%{_libdir}/liblldb.so.*
%{abidir}/liblldb.dump
%{_libdir}/liblldbIntelFeatures.so.*
%{abidir}/liblldbIntelFeatures.dump

%files devel
%{_includedir}/lldb
%{_libdir}/*.so

%files -n python3-lldb
%{python3_sitearch}/lldb

%files doc
%doc CODE_OWNERS.txt

%changelog
* Tue Aug 8 2023 Funda Wang <fundawang@yeah.net> - 16.0.6-1
- New version 16.0.6

* Thu May 18 2023 Funda Wang <fundawang@yeah.net> - 16.0.4-1
- New version 16.0.4

* Sat Apr 15 2023 yuanhui <yuanhui@linux.alibaba.com> - 16.0.1-2
- Optimize the spec file

* Fri Apr 14 2023 Funda Wang <fundawang@yeah.net> - 16.0.1-1
- New version 16.0.1

* Wed Mar 29 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 15.0.7-2
- Del Specific Fields

* Tue Jan 31 2023 Funda Wang <fundwang@yeah.net> - 15.0.7-1
- Import package for anolis 23
